import numpy as np
from matplotlib import cm
import matplotlib.pyplot as plt

default_cmap = cm.get_cmap('rainbow')

def plot_decision(model, X, y=None, width=400, height=400, cmap=None):
    if cmap is None:
        cmap = default_cmap
    # assumes >= 2 features. Plots first as x axis; second as y.
    x0 = X[:, 0]
    y0 = X[:, 1]
    xg = np.linspace(x0.min(), x0.max(), width)
    yg = np.linspace(y0.min(), y0.max(), height)
    xx, yy = np.meshgrid(xg, yg)
    X_grid = np.vstack([xx.ravel(), yy.ravel()]).T
    y_grid = model.predict(X_grid)
    plt.contourf(xx, yy, y_grid.reshape((height, width)), cmap=cmap)
    if y is not None:
        plt.scatter(x0, y0, c=y, cmap=cmap, edgecolor='k')
